@@ -2,6 +2,9 @@
 /*
 ** definition of a node in the tree
 */
+#ifndef FLOAT
+#define FLOAT float   /*see comments in rpart.h */
+#endif
 
 struct split {
     double improve;
